/***********************************************************************************************************************************
Test Assert Macros and Routines when Disabled
***********************************************************************************************************************************/

/***********************************************************************************************************************************
Test Run
***********************************************************************************************************************************/
static void
testRun(void)
{
    FUNCTION_HARNESS_VOID();

    // *****************************************************************************************************************************
    if (testBegin("ASSERT()"))
    {
        TEST_RESULT_VOID(ASSERT(true), "assert true ignored");
        TEST_RESULT_VOID(ASSERT(false || false), "assert false ignored");
    }

    FUNCTION_HARNESS_RETURN_VOID();
}
